DataConnection class

Inheritance
  • Object
  • StreamEventEmitter
  • DataConnection

Constructors

DataConnection(String peerId, FlexiPeer? provider, PeerConnectOption? options)

Properties

connectionId ↔ String
getter/setter pairinherited
controller → StreamController<Event>
finalinherited
dataChannel → RTCDataChannel?
no setter
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String
getter/setter pair
metadata ↔ dynamic
getter/setter pairinherited
open ↔ bool
getter/setter pairinherited
options ↔ PeerConnectOption?
getter/setter pairinherited
peer ↔ String
getter/setter pairinherited
peerConnection ↔ RTCPeerConnection?
getter/setter pairinherited
provider ↔ FlexiPeer?
getter/setter pairinherited
reliable ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialization ↔ SerializationType
getter/setter pair
type ↔ ConnectionType
getter/setter pairinherited-setter

Methods

close() → void
Closes the event emitter, which closes all the listeners in the process.
inherited
closeRequest() → void
inherited
dispose() → void
emit<T>(String type, T data) → void
Emit a event with a specific event type and data type. This will broadcast the message to all listeners that match the same event type and data type.
inherited
emitEvent<T>(Event<T> event) → void
Emit a message on a specific event type and data type. This will broadcast the event to all listeners that match the same event type and data type.
inherited
handleMessage(ServerMessage message) → void
initialize(RTCDataChannel dc) → void
Called by the Negotiator when the DataChannel is ready. */
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<T>([String? type]) → Stream<T>
Attach a listener to the event emitter. Calls the callback whenever there's a new event of the specified type and data type.
inherited
onAny<MessageType>() → Stream<Event<MessageType>>
inherited
once<T>([String? type]) → Future<T>
Same as on but only running once, by returning a Future.
inherited
onceEvent<T extends Event>([String? type]) → Future<T>
Same as onEvent but only running once, by returning a Future.
inherited
onEvent<T extends Event>([String? type]) → Stream<T>
Attach a listener to an emitter. Calls the callback whenever there's a new event of the specified type and data type.
inherited
send(dynamic data) → Future<void>
sendBinary(Uint8List binary) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited